@@ -542,12 +542,13 @@ class MainWindow(QtG.QMainWindow):
         counter = 0
 
         for filename, rectangles in self.box_dictionary.items():
-            counter = counter + 1
+
             if pd.wasCanceled():
                 break
             else:
                 pd.show()
-                pd.setValue(int((counter + 1) * 100 / len(self.box_dictionary.items())))
+                val = int((counter + 1) * 100 / len(self.box_dictionary.items()))
+                pd.setValue(val)
             QtCore.QCoreApplication.instance().processEvents()
 
             box_filename = filename + ".box"
@@ -563,6 +564,7 @@ class MainWindow(QtG.QMainWindow):
             num_writtin_part = num_writtin_part + len(real_rects)
             CoordsIO.write_boxfile_manager(box_file_path, real_rects)
             self.unsaved_changes = False
+            counter = counter + 1
         print(num_writtin_part, "particles written.")
 
     def load_box_files(self):
